/**
 *  Copyright (C) 2009 Emerson Ribeiro de Mello, Roicenir Girardi Rostirolla ; Sérgio Luiz Heinzen
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Copyright (C) 2009 Emerson Ribeiro de Mello, Fernando Fernandes Simão
 *
 *  Este programa é software livre; você pode redistribuí-lo e/ou
 *  modificá-lo sob os termos da Licença Pública Geral GNU, conforme
 *  publicada pela Free Software Foundation; tanto a versão 2 da
 *  Licença como (a seu critério) qualquer versão mais nova.
 *
 *  Este programa é distribuído na expectativa de ser útil, mas SEM
 *  QUALQUER GARANTIA; sem mesmo a garantia implícita de
 *  COMERCIALIZAÇÃO ou de ADEQUAÇÃO A QUALQUER PROPÓSITO EM
 *  PARTICULAR. Consulte a Licença Pública Geral GNU para obter mais
 *  detalhes.
 *
 *  Você deve ter recebido uma cópia da Licença Pública Geral GNU
 *  junto com este programa; se não, escreva para a Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307, USA.
 */
package j2d;

import java.awt.Color;
import java.awt.Graphics;
import java.util.ArrayList;
import javax.swing.ImageIcon;
import javax.swing.JPanel;

public class Painel extends JPanel {

    private ImageIcon rainha2;
    private ImageIcon rainha;
    private ImageIcon vermelha;
    private ImageIcon amarela;
    private boolean preenchido;
    private Pecas[][] tabuleiro;
    private Logica logicaJogo;
    private int selX, selY;
    private boolean jogadorDaVez;
     private ArrayList<String> caminhos;

    public Painel() {

    caminhos = new ArrayList<String>();

        rainha2= new ImageIcon(this.getClass().getResource("damaRainha2.PNG"));
        rainha= new ImageIcon(this.getClass().getResource("damaRainha1.PNG"));
        vermelha = new ImageIcon(this.getClass().getResource("face-angry.png"));
        amarela = new ImageIcon(this.getClass().getResource("face-worried.png"));
        // alterar a cor de fundo do painel
        this.setBackground(Color.WHITE);
        this.preenchido = false;

        this.tabuleiro = new Pecas[8][8];

        for (int lin = 0; lin < 8; lin++) {
            //percorrendo linhas
            // determinando a cor da peça
            boolean cor = (lin > 4) ? true : false;
            for (int col = 0; col < 8; col++) { //percorrendo colunas
                if ((lin != 3 && lin != 4) && (((lin % 2 == 0) && (col % 2 == 1)) || ((lin % 2 == 1) && (col % 2 == 0)))) {
                    this.tabuleiro[lin][col] = new Pecas(cor, true, false, col, lin);
                }
            }
        }
        this.jogadorDaVez = true;
        this.logicaJogo = new Logica(tabuleiro);

        selX = -1;
        selY = -1;

    }

    @Override
    public void paint(Graphics g) {
        
        super.paint(g);
        this.desenharTabuleiro(g);
        this.preencherPecas(g);

    }

    public void limpar() {
        // fazendo o painel ser redesenhado
        this.repaint();
    }

    public void desenharTabuleiro(Graphics g) {
        //preenche a tela de tamanho 400 com
        //quadrados alternados banco e preto de tamanho 50 por 50
        //Graphics g = this.getGraphics();

        for (int i = 0; i < 400; i += 50) {
            for (int j = 0; j < 400; j += 50) {
                if (this.preenchido == false) {
                    g.drawRect(i, j, 50, 50);
                } else {
                    g.fillRect(i, j, 50, 50);
                }
                // novo valor sera' igual ao antigo valor negado
                this.preenchido = !this.preenchido;
            }
            this.preenchido = !this.preenchido;
        }
    }

    public void mover(int fx, int fy) {
        // falta colocar a logica de desenhar a peca selecionada

        Graphics g = this.getGraphics();

        if (tabuleiro[fy][fx] != null) {

            if (tabuleiro[fy][fx].isCor() == this.jogadorDaVez) {

                if (selX != -1) {
                    this.desenharTabuleiro(g);
                    this.preencherPecas(g);
                }
                int x1 = fx * 50 + 5;
                int y1 = fy * 50 + 5;
                g.setColor(Color.yellow);
                g.drawRoundRect(x1, y1, 40, 40, 5, 5);
                selX = fx;
                selY = fy;
            }
        } else {
            if (selX != -1) {
               caminhos = logicaJogo.procurarTodosCaminhos();
                if (logicaJogo.mover(selX, selY, fx, fy) == 0) {
                    tabuleiro[fy][fx] = tabuleiro[selY][selX];
                    tabuleiro[selY][selX] = null;
                    selX = -1;
                    this.jogadorDaVez = !this.jogadorDaVez;
                    this.desenharTabuleiro(g);
                    this.preencherPecas(g);
                }
            }
        }
    }

    public ArrayList<String> getCaminhos() {
        return caminhos;
    }

    public void preencherPecas(Graphics g) {
        //preenche as 3 linhas de baixo com pecas amarelas nos quadrados pretos,
        //e preenche as 3 linhas de cima com pecas vermelhas nos quadrados pretos
        //  Graphics g = this.getGraphics();


        for (int lin = 0; lin
                < 8; lin++) {
            for (int col = 0; col
                    < 8; col++) {

                if (this.tabuleiro[lin][col] != null) {
                    if (tabuleiro[lin][col].isCor() == true && tabuleiro[lin][col].isRainha() == true) {
                        g.drawImage(rainha.getImage(), 10 + (50 * col), 10 + (50 * lin), this);
                    }

                    if (tabuleiro[lin][col].isCor() == false && tabuleiro[lin][col].isRainha() == true) {
                        g.drawImage(rainha2.getImage(), 10 + (50 * col), 10 + (50 * lin), this);
                    }


                    if (tabuleiro[lin][col].isCor() == false && tabuleiro[lin][col].isRainha() == false) {
                        g.drawImage(vermelha.getImage(), 10 + (50 * col), 10 + (50 * lin), this);
                    }

                    if (tabuleiro[lin][col].isCor() == true && tabuleiro[lin][col].isRainha() == false) {
                        g.drawImage(amarela.getImage(), 10 + (50 * col), 10 + (50 * lin), this);
                    }
                }
            }
        }
    }
}